@@ -5,7 +5,7 @@ from bs4 import BeautifulSoup
 from colorama import Fore
 from yarl import URL
 
-from ..base_functions import log, logger, ssl_context
+from ..base_functions import log, logger, ssl_context, make_title_safe
 from ..data_classes import DomainItem
 
 
@@ -14,7 +14,6 @@ class CoomerCrawler:
         self.include_id = include_id
 
     async def fetch(self, session, url: URL):
-        # TODO folder name for posts
         await log("Starting scrape of " + str(url), Fore.WHITE)
         domain_obj = DomainItem('coomer.party', {})
         results = []
@@ -45,8 +44,10 @@ class CoomerCrawler:
 
                 posts = soup.select("a[class=fancy-link]")
                 for post in posts:
-                    post_link = URL("https://coomer.party" + post.get('href'))
-                    results.extend(await self.parse_post(session, post_link, title))
+                    path = post.get('href')
+                    if path:
+                        post_link = URL("https://coomer.party" + path)
+                        results.extend(await self.parse_post(session, post_link, title))
 
                 next_page = soup.select_one('a[title="Next page"]')
                 if next_page:
@@ -68,6 +69,8 @@ class CoomerCrawler:
                 soup = BeautifulSoup(text, 'html.parser')
                 results = []
 
+                title = title + '/' + await make_title_safe(soup.select_one("h1[class=post__title]").text.replace('\n', '').replace("..", ""))
+
                 images = soup.select('a[class="fileThumb"]')
                 for image in images:
                     image_link = URL("https://coomer.party" + image.get('href'))
